@@ -170,7 +170,7 @@ class LambdaResponse(BaseResponse):
 
     def _add_policy(self, request, full_url, headers):
         path = request.path if hasattr(request, "path") else path_url(request.url)
-        function_name = path.split("/")[-2]
+        function_name = unquote(path.split("/")[-2])
         if self.lambda_backend.get_function(function_name):
             statement = self.body
             self.lambda_backend.add_permission(function_name, statement)
@@ -180,7 +180,7 @@ class LambdaResponse(BaseResponse):
 
     def _get_policy(self, request, full_url, headers):
         path = request.path if hasattr(request, "path") else path_url(request.url)
-        function_name = path.split("/")[-2]
+        function_name = unquote(path.split("/")[-2])
         if self.lambda_backend.get_function(function_name):
             out = self.lambda_backend.get_policy_wire_format(function_name)
             return 200, {}, out
@@ -189,7 +189,7 @@ class LambdaResponse(BaseResponse):
 
     def _del_policy(self, request, full_url, headers, querystring):
         path = request.path if hasattr(request, "path") else path_url(request.url)
-        function_name = path.split("/")[-3]
+        function_name = unquote(path.split("/")[-3])
         statement_id = path.split("/")[-1].split("?")[0]
         revision = querystring.get("RevisionId", "")
         if self.lambda_backend.get_function(function_name):
@@ -225,7 +225,7 @@ class LambdaResponse(BaseResponse):
     def _invoke_async(self, request, full_url):
         response_headers = {}
 
-        function_name = self.path.rsplit("/", 3)[-3]
+        function_name = unquote(self.path.rsplit("/", 3)[-3])
 
         fn = self.lambda_backend.get_function(function_name, None)
         if fn:
@@ -236,11 +236,12 @@ class LambdaResponse(BaseResponse):
             return 404, response_headers, "{}"
 
     def _list_functions(self, request, full_url, headers):
+        querystring = self.querystring
+        func_version = querystring.get("FunctionVersion", [None])[0]
         result = {"Functions": []}
 
-        for fn in self.lambda_backend.list_functions():
+        for fn in self.lambda_backend.list_functions(func_version):
             json_data = fn.get_configuration()
-            json_data["Version"] = "$LATEST"
             result["Functions"].append(json_data)
 
         return 200, {}, json.dumps(result)
@@ -298,8 +299,9 @@ class LambdaResponse(BaseResponse):
 
     def _publish_function(self, request, full_url, headers):
         function_name = self.path.rsplit("/", 2)[-2]
+        description = self._get_param("Description")
 
-        fn = self.lambda_backend.publish_function(function_name)
+        fn = self.lambda_backend.publish_function(function_name, description)
         if fn:
             config = fn.get_configuration()
             return 201, {}, json.dumps(config)
@@ -386,7 +388,7 @@ class LambdaResponse(BaseResponse):
             return 404, {}, "{}"
 
     def _put_configuration(self, request):
-        function_name = self.path.rsplit("/", 2)[-2]
+        function_name = unquote(self.path.rsplit("/", 2)[-2])
         qualifier = self._get_param("Qualifier", None)
         resp = self.lambda_backend.update_function_configuration(
             function_name, qualifier, body=self.json_body
@@ -398,7 +400,7 @@ class LambdaResponse(BaseResponse):
             return 404, {}, "{}"
 
     def _put_code(self):
-        function_name = self.path.rsplit("/", 2)[-2]
+        function_name = unquote(self.path.rsplit("/", 2)[-2])
         qualifier = self._get_param("Qualifier", None)
         resp = self.lambda_backend.update_function_code(
             function_name, qualifier, body=self.json_body
@@ -410,7 +412,7 @@ class LambdaResponse(BaseResponse):
             return 404, {}, "{}"
 
     def _get_function_concurrency(self, request):
-        path_function_name = self.path.rsplit("/", 2)[-2]
+        path_function_name = unquote(self.path.rsplit("/", 2)[-2])
         function_name = self.lambda_backend.get_function(path_function_name)
 
         if function_name is None:
@@ -420,7 +422,7 @@ class LambdaResponse(BaseResponse):
         return 200, {}, json.dumps({"ReservedConcurrentExecutions": resp})
 
     def _delete_function_concurrency(self, request):
-        path_function_name = self.path.rsplit("/", 2)[-2]
+        path_function_name = unquote(self.path.rsplit("/", 2)[-2])
         function_name = self.lambda_backend.get_function(path_function_name)
 
         if function_name is None:
@@ -431,7 +433,7 @@ class LambdaResponse(BaseResponse):
         return 204, {}, "{}"
 
     def _put_function_concurrency(self, request):
-        path_function_name = self.path.rsplit("/", 2)[-2]
+        path_function_name = unquote(self.path.rsplit("/", 2)[-2])
         function = self.lambda_backend.get_function(path_function_name)
 
         if function is None:
