@@ -8,7 +8,12 @@ from boto3 import Session
 
 from collections import OrderedDict
 from moto.core import BaseBackend, BaseModel
-from moto.core.utils import iso_8601_datetime_without_milliseconds
+from moto.core.models import ACCOUNT_ID
+from moto.core.utils import (
+    iso_8601_datetime_with_milliseconds,
+    iso_8601_datetime_without_milliseconds,
+)
+from moto.sns.models import sns_backends
 
 from .parsing import ResourceMap, OutputMap
 from .utils import (
@@ -261,19 +266,21 @@ class FakeStack(BaseModel):
     def _add_stack_event(
         self, resource_status, resource_status_reason=None, resource_properties=None
     ):
-        self.events.append(
-            FakeEvent(
-                stack_id=self.stack_id,
-                stack_name=self.name,
-                logical_resource_id=self.name,
-                physical_resource_id=self.stack_id,
-                resource_type="AWS::CloudFormation::Stack",
-                resource_status=resource_status,
-                resource_status_reason=resource_status_reason,
-                resource_properties=resource_properties,
-            )
+
+        event = FakeEvent(
+            stack_id=self.stack_id,
+            stack_name=self.name,
+            logical_resource_id=self.name,
+            physical_resource_id=self.stack_id,
+            resource_type="AWS::CloudFormation::Stack",
+            resource_status=resource_status,
+            resource_status_reason=resource_status_reason,
+            resource_properties=resource_properties,
         )
 
+        event.sendToSns(self.region_name, self.notification_arns)
+        self.events.append(event)
+
     def _add_resource_event(
         self,
         logical_resource_id,
@@ -431,6 +438,7 @@ class FakeEvent(BaseModel):
         resource_status,
         resource_status_reason=None,
         resource_properties=None,
+        client_request_token=None,
     ):
         self.stack_id = stack_id
         self.stack_name = stack_name
@@ -442,6 +450,35 @@ class FakeEvent(BaseModel):
         self.resource_properties = resource_properties
         self.timestamp = datetime.utcnow()
         self.event_id = uuid.uuid4()
+        self.client_request_token = client_request_token
+
+    def sendToSns(self, region, sns_topic_arns):
+        message = """StackId='{stack_id}'
+Timestamp='{timestamp}'
+EventId='{event_id}'
+LogicalResourceId='{logical_resource_id}'
+Namespace='{account_id}'
+ResourceProperties='{resource_properties}'
+ResourceStatus='{resource_status}'
+ResourceStatusReason='{resource_status_reason}'
+ResourceType='{resource_type}'
+StackName='{stack_name}'
+ClientRequestToken='{client_request_token}'""".format(
+            stack_id=self.stack_id,
+            timestamp=iso_8601_datetime_with_milliseconds(self.timestamp),
+            event_id=self.event_id,
+            logical_resource_id=self.logical_resource_id,
+            account_id=ACCOUNT_ID,
+            resource_properties=self.resource_properties,
+            resource_status=self.resource_status,
+            resource_status_reason=self.resource_status_reason,
+            resource_type=self.resource_type,
+            stack_name=self.stack_name,
+            client_request_token=self.client_request_token,
+        )
+
+        for sns_topic_arn in sns_topic_arns:
+            sns_backends[region].publish(message, arn=sns_topic_arn)
 
 
 def filter_stacks(all_stacks, status_filter):
@@ -462,6 +499,13 @@ class CloudFormationBackend(BaseBackend):
         self.exports = OrderedDict()
         self.change_sets = OrderedDict()
 
+    @staticmethod
+    def default_vpc_endpoint_service(service_region, zones):
+        """Default VPC endpoint service."""
+        return BaseBackend.default_vpc_endpoint_service_factory(
+            service_region, zones, "cloudformation", policy_supported=False
+        )
+
     def _resolve_update_parameters(self, instance, incoming_params):
         parameters = dict(
             [
@@ -586,7 +630,7 @@ class CloudFormationBackend(BaseBackend):
         tags=None,
         role_arn=None,
     ):
-        stack_id = generate_stack_id(name)
+        stack_id = generate_stack_id(name, region_name)
         new_stack = FakeStack(
             stack_id=stack_id,
             name=name,
