@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 from .responses import CognitoIdpResponse, CognitoIdpJsonWebKeyResponse
 
-url_bases = ["https?://cognito-idp.(.+).amazonaws.com"]
+url_bases = [r"https?://cognito-idp\.(.+)\.amazonaws.com"]
 
 url_paths = {
     "{0}/$": CognitoIdpResponse.dispatch,
