@@ -1,9 +1,7 @@
 from __future__ import unicode_literals
 from .responses import DatabaseMigrationServiceResponse
 
-url_bases = [
-    "https?://dms.(.+).amazonaws.com",
-]
+url_bases = [r"https?://dms\.(.+)\.amazonaws\.com"]
 
 
 url_paths = {
