@@ -1,3 +1,6 @@
+from moto.dynamodb2.limits import HASH_KEY_MAX_LENGTH, RANGE_KEY_MAX_LENGTH
+
+
 class InvalidIndexNameError(ValueError):
     pass
 
@@ -133,6 +136,25 @@ class ItemSizeToUpdateTooLarge(MockValidationException):
         )
 
 
+class HashKeyTooLong(MockValidationException):
+    # deliberately no space between of and {lim}
+    key_too_large_msg = "One or more parameter values were invalid: Size of hashkey has exceeded the maximum size limit of{lim} bytes".format(
+        lim=HASH_KEY_MAX_LENGTH
+    )
+
+    def __init__(self):
+        super(HashKeyTooLong, self).__init__(self.key_too_large_msg)
+
+
+class RangeKeyTooLong(MockValidationException):
+    key_too_large_msg = "One or more parameter values were invalid: Aggregated size of all range keys has exceeded the size limit of {lim} bytes".format(
+        lim=RANGE_KEY_MAX_LENGTH
+    )
+
+    def __init__(self):
+        super(RangeKeyTooLong, self).__init__(self.key_too_large_msg)
+
+
 class IncorrectOperandType(InvalidUpdateExpression):
     inv_operand_msg = "Incorrect operand type for operator or function; operator or function: {f}, operand type: {t}"
 
@@ -168,6 +190,17 @@ class TransactionCanceledException(ValueError):
 
 class EmptyKeyAttributeException(MockValidationException):
     empty_str_msg = "One or more parameter values were invalid: An AttributeValue may not contain an empty string"
+    # AWS has a different message for empty index keys
+    empty_index_msg = "One or more parameter values are not valid. The update expression attempted to update a secondary index key to a value that is not supported. The AttributeValue for a key attribute cannot contain an empty string value."
 
-    def __init__(self):
-        super(EmptyKeyAttributeException, self).__init__(self.empty_str_msg)
+    def __init__(self, key_in_index=False):
+        super(EmptyKeyAttributeException, self).__init__(
+            self.empty_index_msg if key_in_index else self.empty_str_msg
+        )
+
+
+class UpdateHashRangeKeyException(MockValidationException):
+    msg = "One or more parameter values were invalid: Cannot update attribute {}. This attribute is part of the key"
+
+    def __init__(self, key_name):
+        super(UpdateHashRangeKeyException, self).__init__(self.msg.format(key_name))
