@@ -24,21 +24,19 @@ class EC2ClientError(RESTError):
     request_id_tag_name = "RequestID"
 
     def __init__(self, *args, **kwargs):
-
         kwargs.setdefault("template", "custom_response")
         self.templates["custom_response"] = EC2_ERROR_RESPONSE
-
-        super(EC2ClientError, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 
 class DependencyViolationError(EC2ClientError):
     def __init__(self, message):
-        super(DependencyViolationError, self).__init__("DependencyViolation", message)
+        super().__init__("DependencyViolation", message)
 
 
 class MissingParameterError(EC2ClientError):
     def __init__(self, parameter):
-        super(MissingParameterError, self).__init__(
+        super().__init__(
             "MissingParameter",
             "The request must contain the parameter {0}".format(parameter),
         )
@@ -46,7 +44,7 @@ class MissingParameterError(EC2ClientError):
 
 class InvalidDHCPOptionsIdError(EC2ClientError):
     def __init__(self, dhcp_options_id):
-        super(InvalidDHCPOptionsIdError, self).__init__(
+        super().__init__(
             "InvalidDhcpOptionID.NotFound",
             "DhcpOptionID {0} does not exist.".format(dhcp_options_id),
         )
@@ -54,7 +52,7 @@ class InvalidDHCPOptionsIdError(EC2ClientError):
 
 class MalformedDHCPOptionsIdError(EC2ClientError):
     def __init__(self, dhcp_options_id):
-        super(MalformedDHCPOptionsIdError, self).__init__(
+        super().__init__(
             "InvalidDhcpOptionsId.Malformed",
             'Invalid id: "{0}" (expecting "dopt-...")'.format(dhcp_options_id),
         )
@@ -62,21 +60,21 @@ class MalformedDHCPOptionsIdError(EC2ClientError):
 
 class InvalidKeyPairNameError(EC2ClientError):
     def __init__(self, key):
-        super(InvalidKeyPairNameError, self).__init__(
+        super().__init__(
             "InvalidKeyPair.NotFound", "The keypair '{0}' does not exist.".format(key)
         )
 
 
 class InvalidKeyPairDuplicateError(EC2ClientError):
     def __init__(self, key):
-        super(InvalidKeyPairDuplicateError, self).__init__(
+        super().__init__(
             "InvalidKeyPair.Duplicate", "The keypair '{0}' already exists.".format(key)
         )
 
 
 class InvalidKeyPairFormatError(EC2ClientError):
     def __init__(self):
-        super(InvalidKeyPairFormatError, self).__init__(
+        super().__init__(
             "InvalidKeyPair.Format", "Key is not in valid OpenSSH public key format"
         )
 
@@ -84,14 +82,14 @@ class InvalidKeyPairFormatError(EC2ClientError):
 class InvalidVPCIdError(EC2ClientError):
     def __init__(self, vpc_id):
 
-        super(InvalidVPCIdError, self).__init__(
+        super().__init__(
             "InvalidVpcID.NotFound", "VpcID {0} does not exist.".format(vpc_id),
         )
 
 
 class InvalidSubnetIdError(EC2ClientError):
     def __init__(self, subnet_id):
-        super(InvalidSubnetIdError, self).__init__(
+        super().__init__(
             "InvalidSubnetID.NotFound",
             "The subnet ID '{}' does not exist".format(subnet_id),
         )
@@ -99,7 +97,7 @@ class InvalidSubnetIdError(EC2ClientError):
 
 class InvalidFlowLogIdError(EC2ClientError):
     def __init__(self, count, flow_log_ids):
-        super(InvalidFlowLogIdError, self).__init__(
+        super().__init__(
             "InvalidFlowLogId.NotFound",
             "These flow log ids in the input list are not found: [TotalCount: {0}] {1}".format(
                 count, flow_log_ids
@@ -109,7 +107,7 @@ class InvalidFlowLogIdError(EC2ClientError):
 
 class FlowLogAlreadyExists(EC2ClientError):
     def __init__(self):
-        super(FlowLogAlreadyExists, self).__init__(
+        super().__init__(
             "FlowLogAlreadyExists",
             "Error. There is an existing Flow Log with the same configuration and log destination.",
         )
@@ -117,7 +115,7 @@ class FlowLogAlreadyExists(EC2ClientError):
 
 class InvalidNetworkAclIdError(EC2ClientError):
     def __init__(self, network_acl_id):
-        super(InvalidNetworkAclIdError, self).__init__(
+        super().__init__(
             "InvalidNetworkAclID.NotFound",
             "The network acl ID '{0}' does not exist".format(network_acl_id),
         )
@@ -125,7 +123,7 @@ class InvalidNetworkAclIdError(EC2ClientError):
 
 class InvalidVpnGatewayIdError(EC2ClientError):
     def __init__(self, vpn_gw):
-        super(InvalidVpnGatewayIdError, self).__init__(
+        super().__init__(
             "InvalidVpnGatewayID.NotFound",
             "The virtual private gateway ID '{0}' does not exist".format(vpn_gw),
         )
@@ -133,7 +131,7 @@ class InvalidVpnGatewayIdError(EC2ClientError):
 
 class InvalidVpnGatewayAttachmentError(EC2ClientError):
     def __init__(self, vpn_gw, vpc_id):
-        super(InvalidVpnGatewayAttachmentError, self).__init__(
+        super().__init__(
             "InvalidVpnGatewayAttachment.NotFound",
             "The attachment with vpn gateway ID '{}' and vpc ID '{}' does not exist".format(
                 vpn_gw, vpc_id
@@ -143,7 +141,7 @@ class InvalidVpnGatewayAttachmentError(EC2ClientError):
 
 class InvalidVpnConnectionIdError(EC2ClientError):
     def __init__(self, network_acl_id):
-        super(InvalidVpnConnectionIdError, self).__init__(
+        super().__init__(
             "InvalidVpnConnectionID.NotFound",
             "The vpnConnection ID '{0}' does not exist".format(network_acl_id),
         )
@@ -151,7 +149,7 @@ class InvalidVpnConnectionIdError(EC2ClientError):
 
 class InvalidCustomerGatewayIdError(EC2ClientError):
     def __init__(self, customer_gateway_id):
-        super(InvalidCustomerGatewayIdError, self).__init__(
+        super().__init__(
             "InvalidCustomerGatewayID.NotFound",
             "The customer gateway ID '{0}' does not exist".format(customer_gateway_id),
         )
@@ -159,7 +157,7 @@ class InvalidCustomerGatewayIdError(EC2ClientError):
 
 class InvalidNetworkInterfaceIdError(EC2ClientError):
     def __init__(self, eni_id):
-        super(InvalidNetworkInterfaceIdError, self).__init__(
+        super().__init__(
             "InvalidNetworkInterfaceID.NotFound",
             "The network interface ID '{0}' does not exist".format(eni_id),
         )
@@ -167,7 +165,7 @@ class InvalidNetworkInterfaceIdError(EC2ClientError):
 
 class InvalidNetworkAttachmentIdError(EC2ClientError):
     def __init__(self, attachment_id):
-        super(InvalidNetworkAttachmentIdError, self).__init__(
+        super().__init__(
             "InvalidAttachmentID.NotFound",
             "The network interface attachment ID '{0}' does not exist".format(
                 attachment_id
@@ -177,7 +175,7 @@ class InvalidNetworkAttachmentIdError(EC2ClientError):
 
 class InvalidSecurityGroupDuplicateError(EC2ClientError):
     def __init__(self, name):
-        super(InvalidSecurityGroupDuplicateError, self).__init__(
+        super().__init__(
             "InvalidGroup.Duplicate",
             "The security group '{0}' already exists".format(name),
         )
@@ -185,7 +183,7 @@ class InvalidSecurityGroupDuplicateError(EC2ClientError):
 
 class InvalidSecurityGroupNotFoundError(EC2ClientError):
     def __init__(self, name):
-        super(InvalidSecurityGroupNotFoundError, self).__init__(
+        super().__init__(
             "InvalidGroup.NotFound",
             "The security group '{0}' does not exist".format(name),
         )
@@ -193,7 +191,7 @@ class InvalidSecurityGroupNotFoundError(EC2ClientError):
 
 class InvalidPermissionNotFoundError(EC2ClientError):
     def __init__(self):
-        super(InvalidPermissionNotFoundError, self).__init__(
+        super().__init__(
             "InvalidPermission.NotFound",
             "The specified rule does not exist in this security group",
         )
@@ -201,15 +199,14 @@ class InvalidPermissionNotFoundError(EC2ClientError):
 
 class InvalidPermissionDuplicateError(EC2ClientError):
     def __init__(self):
-        super(InvalidPermissionDuplicateError, self).__init__(
+        super().__init__(
             "InvalidPermission.Duplicate", "The specified rule already exists"
         )
 
 
 class InvalidRouteTableIdError(EC2ClientError):
     def __init__(self, route_table_id):
-
-        super(InvalidRouteTableIdError, self).__init__(
+        super().__init__(
             "InvalidRouteTableID.NotFound",
             "The routeTable ID '{0}' does not exist".format(route_table_id),
         )
@@ -217,7 +214,7 @@ class InvalidRouteTableIdError(EC2ClientError):
 
 class InvalidRouteError(EC2ClientError):
     def __init__(self, route_table_id, cidr):
-        super(InvalidRouteError, self).__init__(
+        super().__init__(
             "InvalidRoute.NotFound",
             "no route with destination-cidr-block {0} in route table {1}".format(
                 cidr, route_table_id
@@ -227,7 +224,7 @@ class InvalidRouteError(EC2ClientError):
 
 class InvalidInstanceIdError(EC2ClientError):
     def __init__(self, instance_id):
-        super(InvalidInstanceIdError, self).__init__(
+        super().__init__(
             "InvalidInstanceID.NotFound",
             "The instance ID '{0}' does not exist".format(instance_id),
         )
@@ -235,7 +232,7 @@ class InvalidInstanceIdError(EC2ClientError):
 
 class InvalidInstanceTypeError(EC2ClientError):
     def __init__(self, instance_type):
-        super(InvalidInstanceTypeError, self).__init__(
+        super().__init__(
             "InvalidInstanceType.NotFound",
             "The instance type '{0}' does not exist".format(instance_type),
         )
@@ -243,7 +240,7 @@ class InvalidInstanceTypeError(EC2ClientError):
 
 class InvalidAMIIdError(EC2ClientError):
     def __init__(self, ami_id):
-        super(InvalidAMIIdError, self).__init__(
+        super().__init__(
             "InvalidAMIID.NotFound",
             "The image id '[{0}]' does not exist".format(ami_id),
         )
@@ -251,7 +248,7 @@ class InvalidAMIIdError(EC2ClientError):
 
 class InvalidAMIAttributeItemValueError(EC2ClientError):
     def __init__(self, attribute, value):
-        super(InvalidAMIAttributeItemValueError, self).__init__(
+        super().__init__(
             "InvalidAMIAttributeItemValue",
             'Invalid attribute item value "{0}" for {1} item type.'.format(
                 value, attribute
@@ -261,7 +258,7 @@ class InvalidAMIAttributeItemValueError(EC2ClientError):
 
 class MalformedAMIIdError(EC2ClientError):
     def __init__(self, ami_id):
-        super(MalformedAMIIdError, self).__init__(
+        super().__init__(
             "InvalidAMIID.Malformed",
             'Invalid id: "{0}" (expecting "ami-...")'.format(ami_id),
         )
@@ -269,14 +266,14 @@ class MalformedAMIIdError(EC2ClientError):
 
 class InvalidSnapshotIdError(EC2ClientError):
     def __init__(self, snapshot_id):
-        super(InvalidSnapshotIdError, self).__init__(
+        super().__init__(
             "InvalidSnapshot.NotFound", ""
         )  # Note: AWS returns empty message for this, as of 2014.08.22.
 
 
 class InvalidVolumeIdError(EC2ClientError):
     def __init__(self, volume_id):
-        super(InvalidVolumeIdError, self).__init__(
+        super().__init__(
             "InvalidVolume.NotFound",
             "The volume '{0}' does not exist.".format(volume_id),
         )
@@ -284,7 +281,7 @@ class InvalidVolumeIdError(EC2ClientError):
 
 class InvalidVolumeAttachmentError(EC2ClientError):
     def __init__(self, volume_id, instance_id):
-        super(InvalidVolumeAttachmentError, self).__init__(
+        super().__init__(
             "InvalidAttachment.NotFound",
             "Volume {0} can not be detached from {1} because it is not attached".format(
                 volume_id, instance_id
@@ -294,7 +291,7 @@ class InvalidVolumeAttachmentError(EC2ClientError):
 
 class InvalidVolumeDetachmentError(EC2ClientError):
     def __init__(self, volume_id, instance_id, device):
-        super(InvalidVolumeDetachmentError, self).__init__(
+        super().__init__(
             "InvalidAttachment.NotFound",
             "The volume {0} is not attached to instance {1} as device {2}".format(
                 volume_id, instance_id, device
@@ -304,7 +301,7 @@ class InvalidVolumeDetachmentError(EC2ClientError):
 
 class VolumeInUseError(EC2ClientError):
     def __init__(self, volume_id, instance_id):
-        super(VolumeInUseError, self).__init__(
+        super().__init__(
             "VolumeInUse",
             "Volume {0} is currently attached to {1}".format(volume_id, instance_id),
         )
@@ -312,21 +309,21 @@ class VolumeInUseError(EC2ClientError):
 
 class InvalidDomainError(EC2ClientError):
     def __init__(self, domain):
-        super(InvalidDomainError, self).__init__(
+        super().__init__(
             "InvalidParameterValue", "Invalid value '{0}' for domain.".format(domain)
         )
 
 
 class InvalidAddressError(EC2ClientError):
     def __init__(self, ip):
-        super(InvalidAddressError, self).__init__(
+        super().__init__(
             "InvalidAddress.NotFound", "Address '{0}' not found.".format(ip)
         )
 
 
 class LogDestinationNotFoundError(EC2ClientError):
     def __init__(self, bucket_name):
-        super(LogDestinationNotFoundError, self).__init__(
+        super().__init__(
             "LogDestinationNotFoundException",
             "LogDestination: '{0}' does not exist.".format(bucket_name),
         )
@@ -334,7 +331,7 @@ class LogDestinationNotFoundError(EC2ClientError):
 
 class InvalidAllocationIdError(EC2ClientError):
     def __init__(self, allocation_id):
-        super(InvalidAllocationIdError, self).__init__(
+        super().__init__(
             "InvalidAllocationID.NotFound",
             "Allocation ID '{0}' not found.".format(allocation_id),
         )
@@ -342,7 +339,7 @@ class InvalidAllocationIdError(EC2ClientError):
 
 class InvalidAssociationIdError(EC2ClientError):
     def __init__(self, association_id):
-        super(InvalidAssociationIdError, self).__init__(
+        super().__init__(
             "InvalidAssociationID.NotFound",
             "Association ID '{0}' not found.".format(association_id),
         )
@@ -350,7 +347,7 @@ class InvalidAssociationIdError(EC2ClientError):
 
 class InvalidVpcCidrBlockAssociationIdError(EC2ClientError):
     def __init__(self, association_id):
-        super(InvalidVpcCidrBlockAssociationIdError, self).__init__(
+        super().__init__(
             "InvalidVpcCidrBlockAssociationIdError.NotFound",
             "The vpc CIDR block association ID '{0}' does not exist".format(
                 association_id
@@ -360,7 +357,7 @@ class InvalidVpcCidrBlockAssociationIdError(EC2ClientError):
 
 class InvalidVPCPeeringConnectionIdError(EC2ClientError):
     def __init__(self, vpc_peering_connection_id):
-        super(InvalidVPCPeeringConnectionIdError, self).__init__(
+        super().__init__(
             "InvalidVpcPeeringConnectionId.NotFound",
             "VpcPeeringConnectionID {0} does not exist.".format(
                 vpc_peering_connection_id
@@ -370,7 +367,7 @@ class InvalidVPCPeeringConnectionIdError(EC2ClientError):
 
 class InvalidVPCPeeringConnectionStateTransitionError(EC2ClientError):
     def __init__(self, vpc_peering_connection_id):
-        super(InvalidVPCPeeringConnectionStateTransitionError, self).__init__(
+        super().__init__(
             "InvalidStateTransition",
             "VpcPeeringConnectionID {0} is not in the correct state for the request.".format(
                 vpc_peering_connection_id
@@ -378,9 +375,27 @@ class InvalidVPCPeeringConnectionStateTransitionError(EC2ClientError):
         )
 
 
+class InvalidServiceName(EC2ClientError):
+    def __init__(self, service_name):
+        super().__init__(
+            "InvalidServiceName",
+            f"The Vpc Endpoint Service '{service_name}' does not exist",
+        )
+
+
+class InvalidFilter(EC2ClientError):
+    def __init__(self, filter_name):
+        super().__init__("InvalidFilter", f"The filter '{filter_name}' is invalid")
+
+
+class InvalidNextToken(EC2ClientError):
+    def __init__(self, next_token):
+        super().__init__("InvalidNextToken", f"The token '{next_token}' is invalid")
+
+
 class InvalidDependantParameterError(EC2ClientError):
     def __init__(self, dependant_parameter, parameter, parameter_value):
-        super(InvalidDependantParameterError, self).__init__(
+        super().__init__(
             "InvalidParameter",
             "{0} can't be empty if {1} is {2}.".format(
                 dependant_parameter, parameter, parameter_value,
@@ -390,7 +405,7 @@ class InvalidDependantParameterError(EC2ClientError):
 
 class InvalidDependantParameterTypeError(EC2ClientError):
     def __init__(self, dependant_parameter, parameter_value, parameter):
-        super(InvalidDependantParameterTypeError, self).__init__(
+        super().__init__(
             "InvalidParameter",
             "{0} type must be {1} if {2} is provided.".format(
                 dependant_parameter, parameter_value, parameter,
@@ -400,14 +415,14 @@ class InvalidDependantParameterTypeError(EC2ClientError):
 
 class InvalidAggregationIntervalParameterError(EC2ClientError):
     def __init__(self, parameter):
-        super(InvalidAggregationIntervalParameterError, self).__init__(
+        super().__init__(
             "InvalidParameter", "Invalid {0}".format(parameter),
         )
 
 
 class InvalidParameterValueError(EC2ClientError):
     def __init__(self, parameter_value):
-        super(InvalidParameterValueError, self).__init__(
+        super().__init__(
             "InvalidParameterValue",
             "Value {0} is invalid for parameter.".format(parameter_value),
         )
@@ -415,7 +430,7 @@ class InvalidParameterValueError(EC2ClientError):
 
 class InvalidParameterValueErrorTagNull(EC2ClientError):
     def __init__(self):
-        super(InvalidParameterValueErrorTagNull, self).__init__(
+        super().__init__(
             "InvalidParameterValue",
             "Tag value cannot be null. Use empty string instead.",
         )
@@ -423,7 +438,7 @@ class InvalidParameterValueErrorTagNull(EC2ClientError):
 
 class InvalidParameterValueErrorUnknownAttribute(EC2ClientError):
     def __init__(self, parameter_value):
-        super(InvalidParameterValueErrorUnknownAttribute, self).__init__(
+        super().__init__(
             "InvalidParameterValue",
             "Value ({0}) for parameter attribute is invalid. Unknown attribute.".format(
                 parameter_value
@@ -433,7 +448,7 @@ class InvalidParameterValueErrorUnknownAttribute(EC2ClientError):
 
 class InvalidGatewayIDError(EC2ClientError):
     def __init__(self, gateway_id):
-        super(InvalidGatewayIDError, self).__init__(
+        super().__init__(
             "InvalidGatewayID.NotFound",
             "The eigw ID '{0}' does not exist".format(gateway_id),
         )
@@ -441,7 +456,7 @@ class InvalidGatewayIDError(EC2ClientError):
 
 class InvalidInternetGatewayIdError(EC2ClientError):
     def __init__(self, internet_gateway_id):
-        super(InvalidInternetGatewayIdError, self).__init__(
+        super().__init__(
             "InvalidInternetGatewayID.NotFound",
             "InternetGatewayID {0} does not exist.".format(internet_gateway_id),
         )
@@ -449,7 +464,7 @@ class InvalidInternetGatewayIdError(EC2ClientError):
 
 class GatewayNotAttachedError(EC2ClientError):
     def __init__(self, internet_gateway_id, vpc_id):
-        super(GatewayNotAttachedError, self).__init__(
+        super().__init__(
             "Gateway.NotAttached",
             "InternetGatewayID {0} is not attached to a VPC {1}.".format(
                 internet_gateway_id, vpc_id
@@ -459,7 +474,7 @@ class GatewayNotAttachedError(EC2ClientError):
 
 class ResourceAlreadyAssociatedError(EC2ClientError):
     def __init__(self, resource_id):
-        super(ResourceAlreadyAssociatedError, self).__init__(
+        super().__init__(
             "Resource.AlreadyAssociated",
             "Resource {0} is already associated.".format(resource_id),
         )
@@ -467,7 +482,7 @@ class ResourceAlreadyAssociatedError(EC2ClientError):
 
 class TagLimitExceeded(EC2ClientError):
     def __init__(self):
-        super(TagLimitExceeded, self).__init__(
+        super().__init__(
             "TagLimitExceeded",
             "The maximum number of Tags for a resource has been reached.",
         )
@@ -475,14 +490,12 @@ class TagLimitExceeded(EC2ClientError):
 
 class InvalidID(EC2ClientError):
     def __init__(self, resource_id):
-        super(InvalidID, self).__init__(
-            "InvalidID", "The ID '{0}' is not valid".format(resource_id)
-        )
+        super().__init__("InvalidID", "The ID '{0}' is not valid".format(resource_id))
 
 
 class InvalidCIDRSubnetError(EC2ClientError):
     def __init__(self, cidr):
-        super(InvalidCIDRSubnetError, self).__init__(
+        super().__init__(
             "InvalidParameterValue",
             "invalid CIDR subnet specification: {0}".format(cidr),
         )
@@ -490,7 +503,7 @@ class InvalidCIDRSubnetError(EC2ClientError):
 
 class RulesPerSecurityGroupLimitExceededError(EC2ClientError):
     def __init__(self):
-        super(RulesPerSecurityGroupLimitExceededError, self).__init__(
+        super().__init__(
             "RulesPerSecurityGroupLimitExceeded",
             "The maximum number of rules per security group " "has been reached.",
         )
@@ -498,7 +511,7 @@ class RulesPerSecurityGroupLimitExceededError(EC2ClientError):
 
 class MotoNotImplementedError(NotImplementedError):
     def __init__(self, blurb):
-        super(MotoNotImplementedError, self).__init__(
+        super().__init__(
             "{0} has not been implemented in Moto yet."
             " Feel free to open an issue at"
             " https://github.com/spulec/moto/issues".format(blurb)
@@ -507,14 +520,12 @@ class MotoNotImplementedError(NotImplementedError):
 
 class FilterNotImplementedError(MotoNotImplementedError):
     def __init__(self, filter_name, method_name):
-        super(FilterNotImplementedError, self).__init__(
-            "The filter '{0}' for {1}".format(filter_name, method_name)
-        )
+        super().__init__("The filter '{0}' for {1}".format(filter_name, method_name))
 
 
 class CidrLimitExceeded(EC2ClientError):
     def __init__(self, vpc_id, max_cidr_limit):
-        super(CidrLimitExceeded, self).__init__(
+        super().__init__(
             "CidrLimitExceeded",
             "This network '{0}' has met its maximum number of allowed CIDRs: {1}".format(
                 vpc_id, max_cidr_limit
@@ -524,7 +535,7 @@ class CidrLimitExceeded(EC2ClientError):
 
 class UnsupportedTenancy(EC2ClientError):
     def __init__(self, tenancy):
-        super(UnsupportedTenancy, self).__init__(
+        super().__init__(
             "UnsupportedTenancy",
             "The tenancy value {0} is not supported.".format(tenancy),
         )
@@ -532,7 +543,7 @@ class UnsupportedTenancy(EC2ClientError):
 
 class OperationNotPermitted(EC2ClientError):
     def __init__(self, association_id):
-        super(OperationNotPermitted, self).__init__(
+        super().__init__(
             "OperationNotPermitted",
             "The vpc CIDR block with association ID {} may not be disassociated. "
             "It is the primary IPv4 CIDR block of the VPC".format(association_id),
@@ -541,7 +552,7 @@ class OperationNotPermitted(EC2ClientError):
 
 class InvalidAvailabilityZoneError(EC2ClientError):
     def __init__(self, availability_zone_value, valid_availability_zones):
-        super(InvalidAvailabilityZoneError, self).__init__(
+        super().__init__(
             "InvalidParameterValue",
             "Value ({0}) for parameter availabilityZone is invalid. "
             "Subnets can currently only be created in the following availability zones: {1}.".format(
@@ -552,7 +563,7 @@ class InvalidAvailabilityZoneError(EC2ClientError):
 
 class NetworkAclEntryAlreadyExistsError(EC2ClientError):
     def __init__(self, rule_number):
-        super(NetworkAclEntryAlreadyExistsError, self).__init__(
+        super().__init__(
             "NetworkAclEntryAlreadyExists",
             "The network acl entry identified by {} already exists.".format(
                 rule_number
@@ -562,14 +573,14 @@ class NetworkAclEntryAlreadyExistsError(EC2ClientError):
 
 class InvalidSubnetRangeError(EC2ClientError):
     def __init__(self, cidr_block):
-        super(InvalidSubnetRangeError, self).__init__(
+        super().__init__(
             "InvalidSubnet.Range", "The CIDR '{}' is invalid.".format(cidr_block)
         )
 
 
 class InvalidCIDRBlockParameterError(EC2ClientError):
     def __init__(self, cidr_block):
-        super(InvalidCIDRBlockParameterError, self).__init__(
+        super().__init__(
             "InvalidParameterValue",
             "Value ({}) for parameter cidrBlock is invalid. This is not a valid CIDR block.".format(
                 cidr_block
@@ -579,7 +590,7 @@ class InvalidCIDRBlockParameterError(EC2ClientError):
 
 class InvalidDestinationCIDRBlockParameterError(EC2ClientError):
     def __init__(self, cidr_block):
-        super(InvalidDestinationCIDRBlockParameterError, self).__init__(
+        super().__init__(
             "InvalidParameterValue",
             "Value ({}) for parameter destinationCidrBlock is invalid. This is not a valid CIDR block.".format(
                 cidr_block
@@ -589,7 +600,7 @@ class InvalidDestinationCIDRBlockParameterError(EC2ClientError):
 
 class InvalidSubnetConflictError(EC2ClientError):
     def __init__(self, cidr_block):
-        super(InvalidSubnetConflictError, self).__init__(
+        super().__init__(
             "InvalidSubnet.Conflict",
             "The CIDR '{}' conflicts with another subnet".format(cidr_block),
         )
@@ -597,7 +608,7 @@ class InvalidSubnetConflictError(EC2ClientError):
 
 class InvalidVPCRangeError(EC2ClientError):
     def __init__(self, cidr_block):
-        super(InvalidVPCRangeError, self).__init__(
+        super().__init__(
             "InvalidVpc.Range", "The CIDR '{}' is invalid.".format(cidr_block)
         )
 
@@ -605,7 +616,7 @@ class InvalidVPCRangeError(EC2ClientError):
 # accept exception
 class OperationNotPermitted2(EC2ClientError):
     def __init__(self, client_region, pcx_id, acceptor_region):
-        super(OperationNotPermitted2, self).__init__(
+        super().__init__(
             "OperationNotPermitted",
             "Incorrect region ({0}) specified for this request."
             "VPC peering connection {1} must be accepted in region {2}".format(
@@ -617,7 +628,7 @@ class OperationNotPermitted2(EC2ClientError):
 # reject exception
 class OperationNotPermitted3(EC2ClientError):
     def __init__(self, client_region, pcx_id, acceptor_region):
-        super(OperationNotPermitted3, self).__init__(
+        super().__init__(
             "OperationNotPermitted",
             "Incorrect region ({0}) specified for this request."
             "VPC peering connection {1} must be accepted or rejected in region {2}".format(
@@ -628,7 +639,7 @@ class OperationNotPermitted3(EC2ClientError):
 
 class OperationNotPermitted4(EC2ClientError):
     def __init__(self, instance_id):
-        super(OperationNotPermitted4, self).__init__(
+        super().__init__(
             "OperationNotPermitted",
             "The instance '{0}' may not be terminated. Modify its 'disableApiTermination' "
             "instance attribute and try again.".format(instance_id),
@@ -637,7 +648,7 @@ class OperationNotPermitted4(EC2ClientError):
 
 class InvalidLaunchTemplateNameError(EC2ClientError):
     def __init__(self):
-        super(InvalidLaunchTemplateNameError, self).__init__(
+        super().__init__(
             "InvalidLaunchTemplateName.AlreadyExistsException",
             "Launch template name already in use.",
         )
@@ -645,7 +656,7 @@ class InvalidLaunchTemplateNameError(EC2ClientError):
 
 class InvalidParameterDependency(EC2ClientError):
     def __init__(self, param, param_needed):
-        super(InvalidParameterDependency, self).__init__(
+        super().__init__(
             "InvalidParameterDependency",
             "The parameter [{0}] requires the parameter {1} to be set.".format(
                 param, param_needed
@@ -655,7 +666,7 @@ class InvalidParameterDependency(EC2ClientError):
 
 class IncorrectStateIamProfileAssociationError(EC2ClientError):
     def __init__(self, instance_id):
-        super(IncorrectStateIamProfileAssociationError, self).__init__(
+        super().__init__(
             "IncorrectState",
             "There is an existing association for instance {0}".format(instance_id),
         )
@@ -663,7 +674,7 @@ class IncorrectStateIamProfileAssociationError(EC2ClientError):
 
 class InvalidAssociationIDIamProfileAssociationError(EC2ClientError):
     def __init__(self, association_id):
-        super(InvalidAssociationIDIamProfileAssociationError, self).__init__(
+        super().__init__(
             "InvalidAssociationID.NotFound",
             "An invalid association-id of '{0}' was given".format(association_id),
         )
@@ -671,7 +682,7 @@ class InvalidAssociationIDIamProfileAssociationError(EC2ClientError):
 
 class InvalidVpcEndPointIdError(EC2ClientError):
     def __init__(self, vpc_end_point_id):
-        super(InvalidVpcEndPointIdError, self).__init__(
+        super().__init__(
             "InvalidVpcEndpointId.NotFound",
             "The VpcEndPoint ID '{0}' does not exist".format(vpc_end_point_id),
         )
@@ -679,7 +690,7 @@ class InvalidVpcEndPointIdError(EC2ClientError):
 
 class InvalidTaggableResourceType(EC2ClientError):
     def __init__(self, resource_type):
-        super(InvalidTaggableResourceType, self).__init__(
+        super().__init__(
             "InvalidParameterValue",
             "'{}' is not a valid taggable resource type for this operation.".format(
                 resource_type
@@ -689,7 +700,7 @@ class InvalidTaggableResourceType(EC2ClientError):
 
 class GenericInvalidParameterValueError(EC2ClientError):
     def __init__(self, attribute, value):
-        super(GenericInvalidParameterValueError, self).__init__(
+        super().__init__(
             "InvalidParameterValue",
             "invalid value for parameter {0}: {1}".format(attribute, value),
         )
@@ -697,7 +708,7 @@ class GenericInvalidParameterValueError(EC2ClientError):
 
 class InvalidSubnetCidrBlockAssociationID(EC2ClientError):
     def __init__(self, association_id):
-        super(InvalidSubnetCidrBlockAssociationID, self).__init__(
+        super().__init__(
             "InvalidSubnetCidrBlockAssociationID.NotFound",
             "The subnet CIDR block with association ID '{0}' does not exist".format(
                 association_id
@@ -707,7 +718,7 @@ class InvalidSubnetCidrBlockAssociationID(EC2ClientError):
 
 class InvalidCarrierGatewayID(EC2ClientError):
     def __init__(self, carrier_gateway_id):
-        super(InvalidCarrierGatewayID, self).__init__(
+        super().__init__(
             "InvalidCarrierGatewayID.NotFound",
             "The CarrierGateway ID '{0}' does not exist".format(carrier_gateway_id),
         )
