@@ -9,6 +9,7 @@ class Subnets(BaseResponse):
     def create_subnet(self):
         vpc_id = self._get_param("VpcId")
         cidr_block = self._get_param("CidrBlock")
+        ipv6_cidr_block = self._get_param("Ipv6CidrBlock")
         availability_zone = self._get_param("AvailabilityZone")
         availability_zone_id = self._get_param("AvailabilityZoneId")
         tags = self._get_multi_param("TagSpecification")
@@ -22,6 +23,7 @@ class Subnets(BaseResponse):
         subnet = self.ec2_backend.create_subnet(
             vpc_id,
             cidr_block,
+            ipv6_cidr_block,
             availability_zone,
             availability_zone_id,
             context=self,
@@ -55,6 +57,26 @@ class Subnets(BaseResponse):
                 )
                 return MODIFY_SUBNET_ATTRIBUTE_RESPONSE
 
+    def associate_subnet_cidr_block(self):
+        ipv6_cidr_block = self._get_param("Ipv6CidrBlock")
+        subnet_id = self._get_param("SubnetId")
+
+        association = self.ec2_backend.associate_subnet_cidr_block(
+            subnet_id, ipv6_cidr_block
+        )
+        template = self.response_template(ASSOCIATE_SUBNET_CIDR_BLOCK_RESPONSE)
+        return template.render(subnet_id=subnet_id, association=association)
+
+    def disassociate_subnet_cidr_block(self):
+        association_id = self._get_param("AssociationId")
+
+        subnet_id, association = self.ec2_backend.disassociate_subnet_cidr_block(
+            association_id
+        )
+        template = self.response_template(DISASSOCIATE_SUBNET_CIDR_BLOCK_RESPONSE)
+        result = template.render(subnet_id=subnet_id, association=association)
+        return result
+
 
 CREATE_SUBNET_RESPONSE = """
 <CreateSubnetResponse xmlns="http://ec2.amazonaws.com/doc/2013-10-15/">
@@ -71,7 +93,19 @@ CREATE_SUBNET_RESPONSE = """
     <mapPublicIpOnLaunch>{{ subnet.map_public_ip_on_launch }}</mapPublicIpOnLaunch>
     <ownerId>{{ subnet.owner_id }}</ownerId>
     <assignIpv6AddressOnCreation>{{ 'false' if not subnet.assign_ipv6_address_on_creation or subnet.assign_ipv6_address_on_creation == 'false' else 'true'}}</assignIpv6AddressOnCreation>
-    <ipv6CidrBlockAssociationSet>{{ subnet.ipv6_cidr_block_associations }}</ipv6CidrBlockAssociationSet>
+    <ipv6CidrBlockAssociationSet>
+    {% for ipv6_association in subnet.ipv6_cidr_block_associations.values() %}
+    {% if ipv6_association.ipv6CidrBlockState == "associated" %}
+      <item>
+        <ipv6CidrBlock>{{ ipv6_association.ipv6CidrBlock }}</ipv6CidrBlock>
+        <associationId>{{ ipv6_association.associationId }}</associationId>
+        <ipv6CidrBlockState>
+          <state>{{ ipv6_association.ipv6CidrBlockState }}</state>
+        </ipv6CidrBlockState>
+      </item>
+    {% endif %}
+    {% endfor %}
+    </ipv6CidrBlockAssociationSet>
     <subnetArn>arn:aws:ec2:{{ subnet._availability_zone.name[0:-1] }}:{{ subnet.owner_id }}:subnet/{{ subnet.id }}</subnetArn>
     <tagSet>
         {% for tag in subnet.get_tags() %}
@@ -109,7 +143,19 @@ DESCRIBE_SUBNETS_RESPONSE = """
         <mapPublicIpOnLaunch>{{ subnet.map_public_ip_on_launch }}</mapPublicIpOnLaunch>
         <ownerId>{{ subnet.owner_id }}</ownerId>
         <assignIpv6AddressOnCreation>{{ 'false' if not subnet.assign_ipv6_address_on_creation or subnet.assign_ipv6_address_on_creation == 'false' else 'true'}}</assignIpv6AddressOnCreation>
-        <ipv6CidrBlockAssociationSet>{{ subnet.ipv6_cidr_block_associations }}</ipv6CidrBlockAssociationSet>
+        <ipv6CidrBlockAssociationSet>
+        {% for ipv6_association in subnet.ipv6_cidr_block_associations.values() %}
+        {% if ipv6_association.ipv6CidrBlockState == "associated" %}
+          <item>
+            <ipv6CidrBlock>{{ ipv6_association.ipv6CidrBlock }}</ipv6CidrBlock>
+            <associationId>{{ ipv6_association.associationId }}</associationId>
+            <ipv6CidrBlockState>
+              <state>{{ ipv6_association.ipv6CidrBlockState }}</state>
+            </ipv6CidrBlockState>
+          </item>
+        {% endif %}
+        {% endfor %}
+        </ipv6CidrBlockAssociationSet>
         <subnetArn>arn:aws:ec2:{{ subnet._availability_zone.name[0:-1] }}:{{ subnet.owner_id }}:subnet/{{ subnet.id }}</subnetArn>
         {% if subnet.get_tags() %}
           <tagSet>
@@ -133,3 +179,31 @@ MODIFY_SUBNET_ATTRIBUTE_RESPONSE = """
   <requestId>7a62c49f-347e-4fc4-9331-6e8eEXAMPLE</requestId>
   <return>true</return>
 </ModifySubnetAttributeResponse>"""
+
+ASSOCIATE_SUBNET_CIDR_BLOCK_RESPONSE = """
+<AssociateSubnetCidrBlock xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
+  <requestId>59dbff89-35bd-4eac-99ed-be587EXAMPLE</requestId>
+  <subnetId>{{ subnet_id }}</subnetId>
+  <ipv6CidrBlockAssociation>
+    <ipv6CidrBlock>{{ association.ipv6CidrBlock }}</ipv6CidrBlock>
+    <ipv6CidrBlockState>
+      <state>{{ association.ipv6CidrBlockState }}</state>
+    </ipv6CidrBlockState>
+    <associationId>{{ association.associationId }}</associationId>
+  </ipv6CidrBlockAssociation>
+</AssociateSubnetCidrBlock>
+"""
+
+DISASSOCIATE_SUBNET_CIDR_BLOCK_RESPONSE = """
+<DisassociateSubnetCidrBlockResponse xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
+  <requestId>59dbff89-35bd-4eac-99ed-be587EXAMPLE</requestId>
+  <subnetId>{{ subnet_id }}</subnetId>
+  <ipv6CidrBlockAssociation>
+    <ipv6CidrBlock>{{ association.ipv6CidrBlock }}</ipv6CidrBlock>
+    <ipv6CidrBlockState>
+      <state>{{ association.ipv6CidrBlockState }}</state>
+    </ipv6CidrBlockState>
+    <associationId>{{ association.associationId }}</associationId>
+  </ipv6CidrBlockAssociation>
+</DisassociateSubnetCidrBlockResponse>
+"""
