@@ -3,7 +3,7 @@ from __future__ import unicode_literals
 from .responses import EKSResponse
 
 url_bases = [
-    "https?://eks.(.+).amazonaws.com",
+    r"https?://eks\.(.+)\.amazonaws.com",
 ]
 
 
