@@ -60,3 +60,12 @@ class ResourceAlreadyExistsException(IoTClientError):
         super(ResourceAlreadyExistsException, self).__init__(
             "ResourceAlreadyExistsException", msg or "The resource already exists."
         )
+
+
+class VersionsLimitExceededException(IoTClientError):
+    def __init__(self, name):
+        self.code = 409
+        super(VersionsLimitExceededException, self).__init__(
+            "VersionsLimitExceededException",
+            "The policy %s already has the maximum number of versions (5)" % name,
+        )
