@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 from .responses import IoTResponse
 
-url_bases = ["https?://iot.(.+).amazonaws.com"]
+url_bases = [r"https?://iot\.(.+)\.amazonaws\.com"]
 
 
 response = IoTResponse()
