@@ -1,17 +1,21 @@
-import sys
 import base64
 
 from .exceptions import InvalidArgumentError
 
 
-if sys.version_info[0] == 2:
-    encode_method = base64.encodestring
-    decode_method = base64.decodestring
-elif sys.version_info[0] == 3:
-    encode_method = base64.encodebytes
-    decode_method = base64.decodebytes
-else:
-    raise Exception("Python version is not supported")
+encode_method = base64.encodebytes
+decode_method = base64.decodebytes
+
+
+PAGINATION_MODEL = {
+    "list_shards": {
+        "input_token": "next_token",
+        "limit_key": "limit",
+        "limit_default": 10000,
+        "page_ending_range_keys": ["ShardId"],
+        "fail_on_invalid_token": False,
+    },
+}
 
 
 def compose_new_shard_iterator(
