@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 from .responses import MediaLiveResponse
 
 url_bases = [
-    "https?://medialive.(.+).amazonaws.com",
+    r"https?://medialive\.(.+)\.amazonaws.com",
 ]
 
 
