@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 from .responses import MediaPackageResponse
 
 url_bases = [
-    "https?://mediapackage.(.+).amazonaws.com",
+    r"https?://mediapackage\.(.+)\.amazonaws.com",
 ]
 
 
