@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 from .responses import ResourceAccessManagerResponse
 
-url_bases = ["https?://ram.(.+).amazonaws.com"]
+url_bases = [r"https?://ram\.(.+)\.amazonaws.com"]
 
 url_paths = {
     "{0}/createresourceshare$": ResourceAccessManagerResponse.dispatch,
