@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 from .responses import Route53
 
-url_bases = ["https?://route53(.*).amazonaws.com"]
+url_bases = [r"https?://route53(.*)\.amazonaws.com"]
 
 
 def tag_response1(*args, **kwargs):
