@@ -648,7 +648,7 @@ RECEIVE_MESSAGE_RESPONSE = """<ReceiveMessageResponse>
                 {% if 'Binary' in value.data_type %}
                 <BinaryValue>{{ value.binary_value }}</BinaryValue>
                 {% else %}
-                <StringValue>{{ value.string_value }}</StringValue>
+                <StringValue><![CDATA[{{ value.string_value }}]]></StringValue>
                 {% endif %}
               </Value>
             </MessageAttribute>
