@@ -60,6 +60,13 @@ class STSBackend(BaseBackend):
     def __init__(self):
         self.assumed_roles = []
 
+    @staticmethod
+    def default_vpc_endpoint_service(service_region, zones):
+        """Default VPC endpoint service."""
+        return BaseBackend.default_vpc_endpoint_service_factory(
+            service_region, zones, "sts"
+        )
+
     def get_session_token(self, duration):
         token = Token(duration=duration)
         return token
